Discover Packages
github.com/cllmhub/cllmhub-cli
internal
versioncheck
package
Version:
v0.6.0
Opens a new window with list of versions in this module.
Published: Apr 2, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Checker performs a background version check against GitHub releases.
New creates a Checker and starts the background check immediately.
Result returns the check result. It blocks briefly (up to the HTTP timeout)
waiting for the background goroutine to finish. Returns nil if no update is
available or the check could not be completed.
type Result struct {
Available bool
LatestVersion string
CurrentVersion string
}
Result holds the outcome of a background version check.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.